.. _examples:


First Steps
===========

This point is intended to show the basic functions of the `DataCube` class. This includes the creation of a DataCube, the reading and writing of a DataCube, as well as the plotting of data.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   first_steps/create_dc
   first_steps/read_write
   first_steps/plot_dc


DataCube Methods
================

The `DataCube` class offers several functions and methods, some of which are presented in this section. For more methods, you can take a look at :ref:`DataCube Operations <DataCube_Ops>`.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   methods/resize
   methods/remove_background

Process DataCube
================

.. toctree::
   :maxdepth: 2
   :titlesonly:

   process/kmeans
   process/smooth_kmeans
   process/isodata
   process/spectral_kmeans
   process/agglomerative_cluster
   process/pca
   process/smooth

Use Template
============

.. toctree::
   :maxdepth: 2
   :titlesonly:

   templates/create_use



